package org.rcisoft.sys.devices.controller;


/*固定导入*/
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.springframework.validation.BindingResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyResultGenUtil;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.exception.CyServiceException;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;


import org.rcisoft.sys.devices.entity.Devices;
import org.rcisoft.sys.devices.service.DevicesService;

import java.util.List;

/**
* Created by cy on 2022年11月24日 下午5:36:12.
*/
@RestController
@RequestMapping("/devices")
public class DevicesController extends CyPaginationController<Devices> {


    @Autowired
    private DevicesService devicesServiceImpl;

    //@PreAuthorize("@cyPerm.hasPerm('sys:ices:add')")
    @CyOpeLogAnno(title = "system-通行设备信息表管理-新增通行设备信息表", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value="添加通行设备信息表", notes="添加通行设备信息表")
    @PostMapping(value = "/add")
    public CyResult add(@Valid Devices devices, BindingResult bindingResult) {
        CyPersistModel data = devicesServiceImpl.persist(devices);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        devices);
    }
    //@PreAuthorize("@cyPerm.hasPerm('sys:ices:delete')")
    @CyOpeLogAnno(title = "system-通行设备信息表管理-删除通行设备信息表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value="删除通行设备信息表", notes="删除通行设备信息表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable String businessId,Devices devices) {
        devices.setBusinessId(businessId);
        CyPersistModel data = devicesServiceImpl.remove(devices);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:ices:update')")
    @CyOpeLogAnno(title = "system-通行设备信息表管理-修改通行设备信息表", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value="修改通行设备信息表", notes="修改通行设备信息表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/update/{businessId:\\w+}")
    public CyResult update(@PathVariable String businessId, @Valid Devices devices, BindingResult bindingResult) {
        devices.setBusinessId(businessId);
        CyPersistModel data = devicesServiceImpl.merge(devices);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        devices);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:ices:query')")
    @CyOpeLogAnno(title = "system-通行设备信息表管理-查询通行设备信息表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询单一通行设备信息表", notes="查询单一通行设备信息表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable String businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        devicesServiceImpl.findById(businessId));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:ices:list')")
    @CyOpeLogAnno(title = "system-通行设备信息表管理-查询通行设备信息表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询通行设备信息表集合", notes="查询通行设备信息表集合")
    @GetMapping(value = "/queryDevicess")
    public CyResult queryDevicess(Devices devices) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
            devicesServiceImpl.findAll(devices));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:ices:list')")
    @CyOpeLogAnno(title = "system-通行设备信息表管理-查询通行设备信息表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="分页查询通行设备信息表集合", notes="分页查询通行设备信息表集合")
    @GetMapping(value = "/queryDevicesByPagination")
    public CyGridModel listByPagination(Devices devices) {
        devicesServiceImpl.findAllByPagination(getPaginationUtility(), devices);
        return getGridModelResponse();
    }

    @CyOpeLogAnno(title = "system-通行设备信息表管理-查询通行设备信息表", businessType = CyLogTypeEnum.EXPORT)
    @ApiOperation(value = "导出通行设备信息表信息", notes = "导出通行设备信息表信息")
    @GetMapping(value = "/export")
    public CyResult outDevices(HttpServletResponse response,Devices devices,@PathVariable @RequestParam(defaultValue = "0") String excelId) {
        String excelName="";
        switch(excelId){
            case "0": excelName="通行设备信息表信息.xls";break;
            case "1": excelName="通行设备信息表信息.xlsx";break;
            case "2": excelName="通行设备信息表信息.csv";break;
        }
        List<Devices> devicesList = devicesServiceImpl.export(devices);
        CyEpExcelUtil.exportExcel(devicesList, "通行设备信息表信息", "通行设备信息表信息", Devices.class, excelName, response);
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
            devicesList);
    }
}
