package org.rcisoft.sys.devices.service.impl;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.aop.CyPageUtilAsp;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.rcisoft.sys.devices.dao.DevicesRepository;
import org.rcisoft.sys.devices.entity.Devices;
import org.rcisoft.sys.devices.service.DevicesService;
import org.rcisoft.core.service.CyBaseService;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;
import org.rcisoft.core.model.CyPageInfo;

import java.util.List;
import lombok.extern.slf4j.Slf4j;

/**
 * Created by cy on 2022年11月24日 下午5:36:12.
 */
@Service
@Transactional(readOnly = true,propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class DevicesServiceImpl extends ServiceImpl<DevicesRepository,Devices>  implements DevicesService {


    /**
    * 保存 通行设备信息表
    * @param devices
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel persist(Devices devices){
        //增加操作
        int line = baseMapper.saveDeviceInfo(devices);
        log.debug(CyUserUtil.getAuthenUsername()+"新增了ID为"+
            devices.getDeviceGuid()+"的通行设备信息表信息");
        return new CyPersistModel(line);
    }

    /**
    * 删除 通行设备信息表
    * @param devices
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(Devices devices){
        int line = baseMapper.realDelete(devices);
        log.debug(CyUserUtil.getAuthenUsername()+"删除了ID为"+
            devices.getBusinessId()+"的通行设备信息表信息");
        return new CyPersistModel(line);
    }
    /**
    * 修改 通行设备信息表
    * @param devices
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(Devices devices){
        baseMapper.updateDeviceInfo(devices);
        log.debug(CyUserUtil.getAuthenUsername()+"修改了ID为"+ devices.getDeviceGuid()+"的通行设备信息表信息");
        return new CyPersistModel(1);
    }

    /**
    * 根据id查询 通行设备信息表
    * @param id
    * @return
    */
    @Override
    public Devices findById(String id){
        return baseMapper.selectById(id);
    }

    /**
    * 分页查询 通行设备信息表
    * @param devices
    * @return
    */
    @Override
    public IPage<Devices> findAllByPagination(CyPageInfo<Devices> paginationUtility,
        Devices devices){
        return baseMapper.queryDevicessPaged(paginationUtility,devices);

    }
    /**
    * 查询list 通行设备信息表
    * @param devices
    * @return
    */
    @Override
    public List<Devices> findAll(Devices devices){
        return baseMapper.queryDevicess(devices);

    }

    /**
    * 导出通行设备信息表
    * @return
    */
    @Override
    public List<Devices> export(Devices devices) {
        List<Devices> devicesList = baseMapper.queryDevicess(devices);
        return devicesList;
    }

    @Override
    public Devices getDeviceInfoByDeviceGuid(String deviceGuid) {
        return baseMapper.getDeviceInfoByGuid(deviceGuid);
    }


}
